@@ -1,6 +1,5 @@
 package PerlCoreMantainer;
-use Mojo::Base 'Mojo::Role';
-#use Mojo::Base -base;
+use Mojo::Role;
 
 sub mantaining_perl {
   say "I'm making improvements for Perl..."
